import {
  select,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  csv,
} from 'd3';


import { dropdownMenu } from './dropdownMenu.js';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { lineChart } from './lineChart';


const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const lineChartG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(854,80)`);


const colorScale = scaleOrdinal()
  .domain(['2010', '2011', '2012', '2013', '2014', '2015', '2016', '2017', '2018'])
  .range([
    '#fff7f3',
    '#fde0dd',
    '#fcc5c0',
    '#fa9fb5',
    '#f768a1',
    '#dd3497',
    '#ae017e',
    '#7a0177',
    '#49006a'
  ]);


const title = 'London Monthly Air Quality: PM2.5 vs. PM10 Particulates';

const circleRadius = 10;
  
const margin = { top: 60, right: 130, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right - 8;
const innerHeight = height - margin.top - margin.bottom;

let data;
let selectedColorValue;
let xColumn;
let yColumn;


const onClick = d => {
  selectedColorValue = d;
  render();
}

loadAndProcessData()
  .then(d => {
    data = d;
    xColumn = d.Date;
    yColumn = d.columns[6];
    render();
});

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  // select('#x-menu')
  //   .call(dropdownMenu, {
  //     options: data.columns.filter(column =>
  //      // column !== 'Date' &&
  //       column !== 'Year' &&
  //       column != 'Month' 
  //     ),
  //     onOptionClicked: onXColumnClicked,
  //     selectedOption: xColumn
  //   });

  select('#y-menu')
    .call(dropdownMenu, {
      options: data.columns.filter(column =>
        column !== 'date' &&
        column !== 'year' &&
        column !== 'Date' &&
        column !== 'Year'
      ),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  


    lineChartG.call(lineChart,{
      data,
      colorScale,
      width,
      height,
      margin,
      title: 'London Monthly Air Quality: '+ yColumn,
      xValue: d => d.date,
      xAxisLabel: 'Month',
      yValue: d => d[yColumn],
      colorValue: d => d.year,
      yAxisLabel: yColumn, 
      innerWidth,
      innerHeight
    });

  colorLegendG.call(colorLegend,{
      colorScale,
      circleRadius: 10,
      spacing: 25,
      textOffset: 20
  });
};